@@ -8,7 +8,7 @@ use Scalar::Util qw(refaddr blessed weaken);
 use Carp;
 use Try::Tiny ();
 
-our @CARP_NOT;
+our @CARP_NOT = qw(Try::Tiny Future);
 
 ## ** lexical attributes to avoid collision of names.
 
@@ -61,7 +61,6 @@ sub try {
     my ($class, $func, @args) = @_;
     if(!defined($func) || ref($func) ne "CODE") {
         $func = sub {
-            local @CARP_NOT = ('Try::Tiny');
             croak("func parameter for try() must be a code-ref");
         };
     }
@@ -187,7 +186,7 @@ foreach my $method (qw(wait_all wait_any needs_all needs_any)) {
     };
 }
 
-our $VERSION = '0.030';
+our $VERSION = '0.040';
 
 1;
 
@@ -199,7 +198,7 @@ Future::Q - a thenable Future like Q module for JavaScript
 
 =head1 VERSION
 
-Version 0.030
+Version 0.040
 
 =head1 SYNOPSIS
 
